==> mtc-starter-security-1.0.0-sources.jar: cool/mtc/security/auth/jwt/JwtAuthAdapter.java <==
package cool.mtc.security.auth.jwt;

import cool.mtc.security.handler.auth.jwt.JwtAuthFailureHandler;
import cool.mtc.security.handler.auth.jwt.JwtAuthSuccessHandler;
import cool.mtc.security.plugin.jwt.JwtTemplate;
import cool.mtc.security.service.SecurityService;
import lombok.RequiredArgsConstructor;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.config.annotation.SecurityConfigurerAdapter;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.web.DefaultSecurityFilterChain;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;

/**
 * @author 明河
 */
@RequiredArgsConstructor
public class JwtAuthAdapter extends SecurityConfigurerAdapter<DefaultSecurityFilterChain, HttpSecurity> {
    private final SecurityService securityService;
    private final JwtTemplate jwtTemplate;

    @Override
    public void configure(HttpSecurity builder) {
        JwtAuthFilter filter = new JwtAuthFilter();
        filter.setAuthenticationManager(builder.getSharedObject(AuthenticationManager.class));
        filter.setAuthenticationSuccessHandler(new JwtAuthSuccessHandler(securityService, jwtTemplate));
        filter.setAuthenticationFailureHandler(new JwtAuthFailureHandler());

        JwtAuthProvider provider = new JwtAuthProvider();
        provider.setSecurityService(securityService);
        provider.setJwtTemplate(jwtTemplate);

        builder.authenticationProvider(provider).addFilterAt(filter, UsernamePasswordAuthenticationFilter.class);
    }
}

==> mtc-starter-security-1.0.5-sources.jar: cool/mtc/security/auth/jwt/JwtAuthAdapter.java <==
package cool.mtc.security.auth.jwt;

import cool.mtc.security.handler.auth.jwt.JwtAuthFailureHandler;
import cool.mtc.security.handler.auth.jwt.JwtAuthSuccessHandler;
import cool.mtc.security.plugin.jwt.JwtTemplate;
import cool.mtc.security.service.SecurityService;
import lombok.RequiredArgsConstructor;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.config.annotation.SecurityConfigurerAdapter;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.web.DefaultSecurityFilterChain;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;

/**
 * @author 明河
 */
@RequiredArgsConstructor
public class JwtAuthAdapter extends SecurityConfigurerAdapter<DefaultSecurityFilterChain, HttpSecurity> {
    private final SecurityService securityService;
    private final JwtTemplate jwtTemplate;
    private final JwtAuthSuccessHandler jwtAuthSuccessHandler;
    private final JwtAuthFailureHandler jwtAuthFailureHandler;

    @Override
    public void configure(HttpSecurity builder) {
        JwtAuthFilter filter = new JwtAuthFilter();
        filter.setAuthenticationManager(builder.getSharedObject(AuthenticationManager.class));
        filter.setAuthenticationSuccessHandler(jwtAuthSuccessHandler);
        filter.setAuthenticationFailureHandler(jwtAuthFailureHandler);

        JwtAuthProvider provider = new JwtAuthProvider();
        provider.setSecurityService(securityService);
        provider.setJwtTemplate(jwtTemplate);

        builder.authenticationProvider(provider).addFilterAt(filter, UsernamePasswordAuthenticationFilter.class);
    }
}
